@@ -3,16 +3,18 @@ package lemmy
 import (
 	"context"
 	"fmt"
+	"net/http"
 	"net/url"
 	"strconv"
+	"time"
 
 	"github.com/mrusme/neonmodem/models/author"
 	"github.com/mrusme/neonmodem/models/forum"
 	"github.com/mrusme/neonmodem/models/post"
 	"github.com/mrusme/neonmodem/models/reply"
 	"github.com/mrusme/neonmodem/system/adapter"
-	"go.arsenm.dev/go-lemmy"
-	"go.arsenm.dev/go-lemmy/types"
+	"go.elara.ws/go-lemmy"
+	"go.elara.ws/go-lemmy/types"
 	"go.uber.org/zap"
 )
 
@@ -100,14 +102,39 @@ func (sys *System) Description() string {
 }
 
 func (sys *System) Load() error {
+	var httpClient *http.Client = nil
+	var httpTransport *http.Transport = http.DefaultTransport.(*http.Transport).
+		Clone()
 	var err error
 
-	url := sys.config["url"]
-	if url == nil {
+	u := sys.config["url"]
+	if u == nil {
 		return nil
 	}
 
-	sys.client, err = lemmy.New(url.(string))
+	proxy := sys.config["proxy"].(string)
+	if proxy != "" {
+		proxyURL, err := url.Parse(proxy)
+		if err != nil {
+			sys.logger.Error(err)
+		} else {
+			sys.logger.Debugf("setting up http proxy transport: %s\n",
+				proxyURL.String())
+			httpTransport = &http.Transport{
+				Proxy: http.ProxyURL(proxyURL),
+			}
+		}
+	}
+
+	httpClient = &http.Client{
+		Transport: httpTransport,
+		Timeout:   time.Second * 10,
+	}
+
+	sys.client, err = lemmy.NewWithClient(
+		u.(string),
+		httpClient,
+	)
 	if err != nil {
 		return err
 	}
@@ -128,7 +155,7 @@ func (sys *System) Load() error {
 }
 
 func (sys *System) ListForums() ([]forum.Forum, error) {
-	resp, err := sys.client.ListCommunities(context.Background(), types.ListCommunities{
+	resp, err := sys.client.Communities(context.Background(), types.ListCommunities{
 		Type: types.NewOptional(types.ListingTypeSubscribed),
 	})
 	if err != nil {
@@ -184,7 +211,6 @@ func (sys *System) ListPosts(forumID string) ([]post.Post, error) {
 
 			Type: t,
 
-			Pinned: i.Post.Stickied,
 			Closed: i.Post.Locked,
 
 			CreatedAt:       createdAt,
@@ -225,8 +251,8 @@ func (sys *System) LoadPost(p *post.Post) error {
 	// 	return err
 	// }
 
-	resp, err := sys.client.Post(context.Background(), types.GetPost{
-		ID: pid,
+	resp, err := sys.client.Comments(context.Background(), types.GetComments{
+		PostID: types.NewOptional[int](pid),
 	})
 	if err != nil {
 		return err
